from volworld_common.api.CA import CA

names = [attr for attr in vars(CA) if not attr.startswith("__")]
names.sort()
values = []

att = "Attributes = {"
init = "A"
for name in names:
    curr_init = name[0]
    if curr_init != init:
        att += "\n"
        init = curr_init
    value = getattr(CA, name)
    assert value not in values, f"{value} is already in values"
    att += f"\n\"{name}\": \"{value}\","

att += "\n\"___Error___\": \"err\""
att += "\n}"

print(f"\n\n\n{att}\n\n\n")


from typing import Final

class GaiaDefaultTutorialSite:
    class InitTutorial1:
        UUID: Final[str] = "c42edc7f-f382-40c6-b042-68858daa8ec3"
    class InitTutorial2:
        UUID: Final[str] = "26630f2f-ab60-417f-bae9-a3cb7385692f"
    class InitTutorial3:
        UUID: Final[str] = "5a2edb29-5d2b-49af-8456-57e332a33e8f"
    class InitTutorial4:
        UUID: Final[str] = "608eb0b8-8472-44db-82a8-46ec6fc390c8"
    class InitTutorial5:
        UUID: Final[str] = "ff34c88d-9f61-4002-98f9-aa54689f02f4"



from typing import Final

class NullId:
    BIGINT: Final[int] = 0
    UUID: Final[int] = "7e87861c-e9fe-47c5-b6f3-a11a7d4ecb5f"
    NAME: Final[str] = "null"

class EmptyId:
    BIGINT: Final[int] = -1
    UUID: Final[int] = "67728fba-ad15-49ed-b8c4-37971134175a"
    NAME: Final[str] = "empty"


from typing import Final

class AthenaDefaultThreeColorsPuzzle:
    class Square5:
        UUID: Final[str] = "8a289f34-12d0-4844-92da-cb51eb5371de"
    class Square6:
        UUID: Final[str] = "9440be59-6965-4279-9dee-504bc8056b75"
    class Square7:
        UUID: Final[str] = "bbeb7551-fd00-4542-b096-17ad8d4c97b8"
    class Square8:
        UUID: Final[str] = "7662b250-7d1b-4d05-9448-69aca320b0da"
    class Square9:
        UUID: Final[str] = "1f1a888c-f3b5-42aa-b17c-93658bd6d638"

class AthenaDefaultFourColorsPuzzle:
    class Square5:
        UUID: Final[str] = "db7af395-4e5a-48da-90f3-139c3aaf8185"
    class Square6:
        UUID: Final[str] = "c25bafc1-2e2f-4ecb-adbb-d93e5e940edc"
    class Square7:
        UUID: Final[str] = "e1baf85b-20dd-4e49-94ba-a50787212c8c"
    class Square8:
        UUID: Final[str] = "a84fa989-265e-4258-844b-de1e48421424"
    class Square9:
        UUID: Final[str] = "e1baf85b-20dd-4e49-94ba-a50787212c8c"





import time
# @ref https://stackoverflow.com/questions/5849800/what-is-the-python-equivalent-of-matlabs-tic-and-toc-functions


class Timer(object):
    def __init__(self, name=None):
        self.name = name

    def __enter__(self):
        self.tstart = time.time()

    def __exit__(self, type, value, traceback):
        dt = time.time() - self.tstart
        if self.name:
            print('dt [Finished][%s] >>> Elapsed: %s s' % (self.name, dt))
        else:
            print('dt >>> Elapsed: %s s' % dt)



from enum import IntEnum

class CompassSphereType(IntEnum):

    SaltFlash = 11,
    Aggregation = 12,
    Crystal = 13,
    DeepBlue = 14,
    GoldPiece = 15,
    Orbital = 16,
    StabLake = 17,
    Wheel = 18,
    Windmill = 19,

